@@ -4,8 +4,8 @@
 #  --> https://CRAN.R-project.org/package=spam              #
 #  --> https://CRAN.R-project.org/package=spam64            #
 #  --> https://git.math.uzh.ch/reinhard.furrer/spam         #
-# by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
-#    Roman Flury [ctb], Daniel Gerber [ctb],                #
+# by Reinhard Furrer [aut, cre], Florian Gerber [aut],      #
+#    Roman Flury [aut], Daniel Gerber [ctb],                #
 #    Kaspar Moesinger [ctb]                                 #
 # HEADER END ################################################
 
@@ -30,5 +30,6 @@ test_that("diff", {
     spamtest_eq(diff(x,d=2), diff(as.spam(x), d=2))
     spamtest_eq(diff(x,d=4), diff(as.spam(x), d=4))
     spamtest_eq(diff(x,2, d=2), diff(as.spam(x),2, d=2))
-    expect_equal(diff(x,4, d=4), diff(as.spam(x),4, d=4))
+# The following works on R >=4.6
+#    expect_equal(diff(x,4, d=4), as.matrix(diff(as.spam(x),4, d=4)))
 })
